# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["ComputerTypeTextParams"]


class ComputerTypeTextParams(TypedDict, total=False):
    tab_id: str

    text: str
