# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["ComputerSetViewportParams"]


class ComputerSetViewportParams(TypedDict, total=False):
    height: int

    scale_factor: float

    tab_id: str

    width: int
