# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .computer_response import ComputerResponse

__all__ = ["ComputerListResponse"]

ComputerListResponse: TypeAlias = List[ComputerResponse]
